@@ -1,3 +1,5 @@
+
+
 // DasherModel.h
 //
 // Copyright (c) 2001-2005 David Ward
@@ -5,6 +7,10 @@
 #ifndef __DasherModel_h__
 #define __DasherModel_h__
 
+#ifndef WIN32
+#include "config.h"
+#endif
+
 #include "../Common/NoClones.h"
 
 #include "LanguageModelling/LanguageModel.h"
@@ -12,8 +18,14 @@
 #include "DasherNode.h"
 #include "DasherComponent.h"
 #include "Alphabet/Alphabet.h"
+#include "Alphabet/AlphIO.h"
 #include "AlphabetManagerFactory.h"
 #include "ControlManagerFactory.h"
+
+#ifdef JAPANESE
+#include "ConversionManagerFactory.h"
+#endif
+
 #include <math.h>
 #include "DasherTypes.h"
 #include "FrameRate.h"
@@ -62,7 +74,7 @@ class Dasher::CDasherModel:public Dasher::CDasherComponent, private NoClones
     idJapanese = 4
   } LanguageModelID;
 
-  CDasherModel(CEventHandler * pEventHandler, CSettingsStore * pSettingsStore, CDasherInterfaceBase * pDashIface);
+  CDasherModel(CEventHandler * pEventHandler, CSettingsStore * pSettingsStore, CDasherInterfaceBase * pDashIface, CAlphIO *pAlphIO);
   ~CDasherModel();
 
   bool WriteLMToFile(const std::string &strFilename) {
@@ -109,12 +121,13 @@ class Dasher::CDasherModel:public Dasher::CDasherComponent, private NoClones
   }                             // Use or start at this bitrate
   //void SetMaxBitrate(double MaxRate) {m_dMaxRate=MaxRate;m_fr.SetMaxBitrate(MaxRate);} // Cap any adaption at this rate
 
-  std::string GroupLabel(int group) const {
-    return m_pcAlphabet->GetGroupLabel(group);
-  }
-  int GroupColour(int group) const {
-    return m_pcAlphabet->GetGroupColour(group);
-  }
+/*   std::string GroupLabel(int group) const { */
+/*     return m_pcAlphabet->GetGroupLabel(group); */
+/*   } */
+/*   int GroupColour(int group) const { */
+/*     return m_pcAlphabet->GetGroupColour(group); */
+/*   } */
+
   void SetContext(std::string & sNewContext);
 
   // functions returning private data (read only access)
@@ -136,9 +149,9 @@ class Dasher::CDasherModel:public Dasher::CDasherComponent, private NoClones
 
   void Tap_on_display(myint, myint, unsigned long Time, Dasher::VECTOR_SYMBOL_PROB* pAdded = NULL, int* pNumDeleted = NULL);  // evolves the current viewpoint
 
-  void GoTo(double, myint);     // jumps to a new viewpoint
-  void NewGoTo(myint n1, myint n2, int style);
-  double Plan_new_goto_coords(int iRxnew, myint mousey, int *iSteps, myint *o1, myint *o2 , myint *n1, myint *n2);
+/*   void GoTo(double, myint);     // jumps to a new viewpoint */
+   void NewGoTo(myint n1, myint n2, int style);
+   double Plan_new_goto_coords(int iRxnew, myint mousey, int *iSteps, myint *o1, myint *o2 , myint *n1, myint *n2); 
 
   void Start();                 // initializes the data structure
 
@@ -172,19 +185,7 @@ class Dasher::CDasherModel:public Dasher::CDasherComponent, private NoClones
 
   void Reparent_root(int lower, int upper);     // change back to the previous root
 
-  int GetMode() {
-    int mode;
-
-    if(GetBoolParameter(BP_NUMBER_DIMENSIONS))
-      mode = 1;
-    else if(GetBoolParameter(BP_EYETRACKER_MODE))
-      mode = 2;
-    else
-      mode = 0;
-
-    return mode;
-  }
-
+ 
   void ResetNats() {
     total_nats = 0;
   }
@@ -195,27 +196,6 @@ class Dasher::CDasherModel:public Dasher::CDasherComponent, private NoClones
 
   myint PlotGoTo(myint MouseX, myint MouseY);
 
-/*   void NewControlTree(ControlTree * tree) { */
-/*     m_pControltree = tree; */
-/*   } */
-/*   ControlTree *GetControlTree() const { */
-/*     return m_pControltree; */
-/*   } */
-
-
-/*   struct CRange { */
-/*     CRange(myint _iMin, myint _iMax):iMin(_iMin), iMax(_iMax) { */
-/*     } */
-/*     CRange() { */
-/*     } */
-/*     myint iMin; */
-/*     myint iMax; */
-/*   }; */
-
-/*   void SetActive(const CRange & range) { */
-/*     m_Active = range; */
-/*   } */
-
   void EnterText(CLanguageModel::Context Context, std::string TheText) const;
   void LearnText(CLanguageModel::Context Context, std::string * TheText, bool IsMore);
 
@@ -230,6 +210,11 @@ class Dasher::CDasherModel:public Dasher::CDasherComponent, private NoClones
     return m_pcAlphabet->GetControlSymbol();
   }
 
+  symbol GetStartConversionSymbol() const {
+    return m_pcAlphabet->GetStartConversionSymbol();
+  }
+
+
   const std::string & GetDisplayText(int iSymbol) const {
     return m_pcAlphabet->GetDisplayText(iSymbol);
   }
@@ -238,6 +223,10 @@ class Dasher::CDasherModel:public Dasher::CDasherComponent, private NoClones
     return *m_pcAlphabet;
   }
 
+  CAlphabet *GetAlphabetNew() const {
+    return m_pcAlphabet;
+  }
+
   CDasherNode *Get_node_under_crosshair();    // Needed for Game Mode
   
   myint GetGameModePointerLoc() {
@@ -245,10 +234,16 @@ class Dasher::CDasherModel:public Dasher::CDasherComponent, private NoClones
   }
   
   CDasherNode *GetRoot( int iType, CDasherNode *pParent, int iLower, int iUpper, void *pUserData ) {
-    if( iType == 0 )
+    switch(iType) {
+    case 0:
       return m_pAlphabetManagerFactory->GetRoot(pParent, iLower, iUpper, pUserData);
-    else
+    case 1:
       return m_pControlManagerFactory->GetRoot(pParent, iLower, iUpper, pUserData);
+#ifdef JAPANESE
+    case 2:
+      return m_pConversionManagerFactory->GetRoot(pParent, iLower, iUpper, pUserData);
+#endif
+    }
   };
   
   // FIXME - only public temporarily
@@ -266,18 +261,20 @@ class Dasher::CDasherModel:public Dasher::CDasherComponent, private NoClones
      m_pControlManagerFactory->ConnectNode(iChild, iParent, iAfter);
   }
 
+  void DisconnectNode(int iChild, int iParent) {
+     m_pControlManagerFactory->DisconnectNode(iChild, iParent);
+  }
+
   void Push_Node(CDasherNode * pNode);  // give birth to children
 
   bool m_bContextSensitive;
 
   std::string m_strContextBuffer;
 
-  void RenderToView(CDasherView *pView);
-  bool RenderToView(CDasherView *pView, int iMouseX, int iMouseY, bool bRedrawDisplay);
+  bool RenderToView(CDasherView *pView, bool bRedrawDisplay);
 
   bool CheckForNewRoot(CDasherView *pView);
 
-  void ClickTo(int x, int y, int width, int height, CDasherView *pView);
   void ScheduleZoom(int dasherx, int dashery);
  
  private:
@@ -290,7 +287,7 @@ class Dasher::CDasherModel:public Dasher::CDasherComponent, private NoClones
 
   CLanguageModel *m_pLanguageModel;     // pointer to the language model
 
-  const CAlphabet *m_pcAlphabet;        // pointer to the alphabet
+  CAlphabet *m_pcAlphabet;        // pointer to the alphabet
 
   CLanguageModel::Context LearnContext; // Used to add data to model as it is entered
 
@@ -342,6 +339,10 @@ class Dasher::CDasherModel:public Dasher::CDasherComponent, private NoClones
   CAlphabetManagerFactory *m_pAlphabetManagerFactory;
   CControlManagerFactory *m_pControlManagerFactory;
 
+#ifdef JAPANESE
+  CConversionManagerFactory *m_pConversionManagerFactory;
+#endif
+
   struct SGotoItem {
     myint iN1;
     myint iN2;
