@@ -29,7 +29,7 @@ using namespace WinUTF8;
 
 /////////////////////////////////////////////////////////////////////////////
 
-CEdit::CEdit() : m_FontSize(0), m_FontName(""), FileHandle(INVALID_HANDLE_VALUE), 
+CEdit::CEdit(CAppSettings *pAppSettings) : m_FontSize(0), m_FontName(""), FileHandle(INVALID_HANDLE_VALUE), 
 				m_FilenameGUI(0), threadid(0), targetwindow(0),
 #ifndef DASHER_WINCE
 pVoice(0),
@@ -37,6 +37,8 @@ pVoice(0),
 				textentry(false) 
 {
   
+m_pAppSettings = pAppSettings;
+
   CodePage = GetUserCodePage();
   m_Font = GetCodePageFont(CodePage, 14);
 
@@ -63,16 +65,14 @@ pVoice(0),
 
 HWND CEdit::Create(HWND hParent, bool bNewWithDate)
 {
-	HWND hWnd = CWindowImpl<CEdit>::Create(hParent, NULL, NULL, ES_NOHIDESEL | WS_CHILD | ES_MULTILINE | WS_VSCROLL | WS_VISIBLE, WS_EX_CLIENTEDGE);
+	m_hWnd = CWindowImpl<CEdit>::Create(hParent, NULL, NULL, ES_NOHIDESEL | WS_CHILD | ES_MULTILINE | WS_VSCROLL | WS_VISIBLE, WS_EX_CLIENTEDGE);
 
 	
 	Tstring WindowTitle;
 	WinLocalisation::GetResourceString(IDS_APP_TITLE, &WindowTitle);
 	m_FilenameGUI = new CFilenameGUI(hParent, WindowTitle.c_str(), bNewWithDate);
 
-  m_filename = m_FilenameGUI->GetFilename();
-
-	return hWnd;
+	return m_hWnd;
 }
 
 
@@ -227,28 +227,6 @@ void CEdit::TimeStampNewFiles(bool Value) {
   m_FilenameGUI->SetNewWithDate(Value);
 }
 
-bool CEdit::QueryClose() {
-  switch (m_FilenameGUI->QuerySaveFirst()) {
-  case IDYES:
-    if(!Save()) {
-      if(!TSaveAs(m_FilenameGUI->SaveAs()))
-        return false;
-      else
-        return true;
-    }
-    else {
-      return true;
-    }
-    break;
-  case IDNO:
-    return true;
-    break;
-  default:
-    return false;
-    break;
-  }
-}
-
 void CEdit::New() {
   switch (m_FilenameGUI->QuerySaveFirst()) {
   case IDYES:
@@ -322,7 +300,7 @@ void CEdit::TNew(const Tstring &filename) {
   AppendMode = false;
   Clear();
 
-  m_pDasherInterface->InvalidateContext();
+  m_pDasherInterface->InvalidateContext(true);
 }
 
 bool CEdit::TOpen(const Tstring &filename) {
@@ -481,35 +459,37 @@ void CEdit::SetFont(string Name, long Size) {
 
 void CEdit::SetInterface(Dasher::CDasherInterfaceBase *DasherInterface) {
   CDashEditbox::SetInterface(DasherInterface);
-
-  CodePage = EncodingToCP(m_pDasherInterface->GetAlphabetType());
+// TODO: Reimplement if necessary
+//  CodePage = EncodingToCP(m_pDasherInterface->GetAlphabetType());
   SetFont(m_FontName, m_FontSize);
 
 }
 
 void CEdit::write_to_file() {
-  const string & TrainFile = m_pDasherInterface->GetTrainFile();
-  if(TrainFile == "")
-    return;
-  Tstring TTrainFile;
-  UTF8string_to_wstring(TrainFile, TTrainFile);
+  // TODO: Reimplement if necessary
 
-  HANDLE hFile = CreateFile(TTrainFile.c_str(),
-                            GENERIC_WRITE, 0, NULL, OPEN_ALWAYS, FILE_ATTRIBUTE_NORMAL, 0);
+  //const string & TrainFile = m_pDasherInterface->GetTrainFile();
+  //if(TrainFile == "")
+  //  return;
+  //Tstring TTrainFile;
+  //UTF8string_to_wstring(TrainFile, TTrainFile);
 
-  if(hFile == INVALID_HANDLE_VALUE) {
-    OutputDebugString(TEXT("Can not open file\n"));
-  }
-  else {
-    DWORD NumberOfBytesWritten;
-    SetFilePointer(hFile, 0, NULL, FILE_END);
-    for(unsigned int i = 0; i < m_Output.size(); i++) {
-      WriteFile(hFile, &m_Output[i], 1, &NumberOfBytesWritten, NULL);
-    }
+  //HANDLE hFile = CreateFile(TTrainFile.c_str(),
+  //                          GENERIC_WRITE, 0, NULL, OPEN_ALWAYS, FILE_ATTRIBUTE_NORMAL, 0);
 
-    m_Output = "";
-    CloseHandle(hFile);
-  }
+  //if(hFile == INVALID_HANDLE_VALUE) {
+  //  OutputDebugString(TEXT("Can not open file\n"));
+  //}
+  //else {
+  //  DWORD NumberOfBytesWritten;
+  //  SetFilePointer(hFile, 0, NULL, FILE_END);
+  //  for(unsigned int i = 0; i < m_Output.size(); i++) {
+  //    WriteFile(hFile, &m_Output[i], 1, &NumberOfBytesWritten, NULL);
+  //  }
+
+  //  m_Output = "";
+  //  CloseHandle(hFile);
+  //}
 }
 
 void CEdit::get_new_context(string &str, int max) {
@@ -541,7 +521,8 @@ void CEdit::output(const std::string &sText) {
 
   InsertText(String);
 
-  if(targetwindow != NULL && textentry == true) {
+//  if(targetwindow != NULL && textentry == true) {
+  if(m_pAppSettings->GetLongParameter(APP_LP_STYLE) == 2) {
     const char *DisplayText = sText.c_str();
 #ifdef UNICODE
     if(DisplayText[0] == 0xd && DisplayText[1] == 0xa) {
@@ -624,7 +605,7 @@ void CEdit::Move(int iDirection, int iDist) {
   if(iDirection == EDIT_FORWARDS) {
     switch(iDist) {
     case EDIT_CHAR:
-      if(iStart != iEnd)
+      //if(iStart != iEnd)
         ++iEnd;
       iStart = iEnd;
       break;
@@ -862,16 +843,7 @@ LRESULT CEdit::OnLButtonDown(UINT message, WPARAM wParam, LPARAM lParam, BOOL& b
 
 LRESULT CEdit::OnLButtonUp(UINT message, WPARAM wParam, LPARAM lParam, BOOL& bHandled)
 {
-    // This doesn't seem to work...
-    // if we click the mouse in the edit control, update the Dasher display
-
-	// DJW20060101 - I put the following line back in, and it half-works
-	// The Dasher display resets to the root context, rather than pulling the
-	// context from the edit control
-//	m_pDasherInterface->ChangeEdit();
-  //  InvalidateRect(NULL, FALSE);
-
-  m_pDasherInterface->InvalidateContext();
+  m_pDasherInterface->InvalidateContext(false);
 
 	bHandled = FALSE; // let the EDIT class handle it
 	return 0;
@@ -980,7 +952,9 @@ void CEdit::deletetext(const std::string &sText) {
   // newline pair, but we're now assuming we'll never have two real characters for
   // a single symbol
 
-  if(targetwindow != NULL && textentry == true) {
+//  if(targetwindow != NULL && textentry == true) {
+if(m_pAppSettings->GetLongParameter(APP_LP_STYLE) == 2) {
+
 #ifdef _UNICODE
     fakekey[0].type = fakekey[1].type = INPUT_KEYBOARD;
     fakekey[0].ki.wVk = fakekey[1].ki.wVk = VK_BACK;
@@ -1174,6 +1148,13 @@ void CEdit::outputcontrol(void *pointer, int data, int type) {
 
 void CEdit::speak(int what) {
 
+  if(!m_pAppSettings->GetBoolParameter(APP_BP_SPEECH_MODE))
+    return;
+
+  // TODO: Horrible hack - don't speak in direct entry mode
+  if(m_pAppSettings->GetLongParameter(APP_LP_STYLE) == 2)
+    return;
+
 // Todo - put this in a separate class
 
 #ifndef DASHER_WINCE
@@ -1226,25 +1207,3 @@ void CEdit::SetNewWithDate(bool bNewWithDate) {
   if(m_FilenameGUI)
     m_FilenameGUI->SetNewWithDate(bNewWithDate);
 }
-
-std::string CEdit::GetContext(int iLength) {
-  LRESULT lResult(SendMessage(m_hWnd, EM_GETHANDLE, 0, 0));
-  HLOCAL hMemoryHandle((HLOCAL)lResult);
-
-  int iOffset;
-  SendMessage(m_hWnd, EM_GETSEL, (WPARAM)&iOffset, 0);
-
-  int iStart(iOffset - iLength);
-
-  if(iStart < 0)
-    iStart = 0;
-
-  LPVOID pBuffer(LocalLock(hMemoryHandle));
-  std::wstring strContext((TCHAR *)pBuffer + iStart, iOffset - iStart);
-  LocalUnlock(hMemoryHandle);
-
-  std::string strReturnValue;
-  WinUTF8::wstring_to_UTF8string(strContext, strReturnValue);
-
-  return strReturnValue;
-}
\ No newline at end of file
