@@ -25,9 +25,9 @@ extern CComModule _Module;
 #endif
 
 #include "../../DasherCore/DashEdit.h"
+#include "../AppSettings.h"
 
 #include <Oleacc.h>
-#include <string>
 
 class CCanvas;
 class CFilenameGUI;
@@ -49,7 +49,7 @@ class CEdit	:	public Dasher::CDashEditbox,
 {
 public:
 
-	CEdit();
+	CEdit(CAppSettings *pAppSettings);
 	~CEdit();
 
 	HWND Create(HWND hParent, bool bNewWithDate);
@@ -95,7 +95,6 @@ public:
 	bool Save();
 	// Functions for Windows GUI to call
 	void New();
-  bool QueryClose();
 	void Open();
 	void OpenAppendMode();
 	void SaveAs();
@@ -150,8 +149,6 @@ public:
 
   void SetNewWithDate(bool bNewWithDate);
 
-  std::string GetContext(int iLength);
-
 protected:
 	bool m_dirty;
 	LRESULT WndProc(HWND Window, UINT message, WPARAM wParam, LPARAM lParam);
@@ -197,6 +194,9 @@ private:
 
 	void InsertText(Tstring InsertText);  // add symbol to edit control
 
+  CAppSettings *m_pAppSettings;
+  HWND m_hWnd;
+
 	//      CCanvas* Canvas;
 };
 
